aind\_data\_schema package
==========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   aind_data_schema.ephys
   aind_data_schema.imaging

Submodules
----------

aind\_data\_schema.data\_description module
-------------------------------------------

.. automodule:: aind_data_schema.data_description
   :members:
   :undoc-members:
   :show-inheritance:

aind\_data\_schema.procedures module
------------------------------------

.. automodule:: aind_data_schema.procedures
   :members:
   :undoc-members:
   :show-inheritance:

aind\_data\_schema.processing module
------------------------------------

.. automodule:: aind_data_schema.processing
   :members:
   :undoc-members:
   :show-inheritance:

aind\_data\_schema.subject module
---------------------------------

.. automodule:: aind_data_schema.subject
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_data_schema
   :members:
   :undoc-members:
   :show-inheritance:
